@@ -1,4 +1,4 @@
-from powerml.utils.run_ai import run_ai
+from powerml.utils.run_ai import query_powerml
 import re
 
 
@@ -9,9 +9,9 @@ def more_sql_like_this(example, n=1):
     prompt_append = f'Write %d more example(s) that use the same schema, but answer a different business question than the above. List them below.\n\nExample 1. ' % (
         n)
     prompt = f'Example: {example}\n\n{prompt_append}'
-    text = run_ai(prompt,
-                  max_tokens=256,
-                  )
+    text = query_powerml(prompt,
+                         max_tokens=256,
+                         )
     results = re.split("Example \d+\.", text)
     results = [strip_end_of_query(r).strip() for r in results]
     return results
