@@ -31,6 +31,16 @@ class AutocompleteSQLModel:
         self.example_queries = example_queries
 
     def predict(self, sql_prompt):
+        """
+        Parameters
+        ----------
+        sql_prompt: string
+            The beginning of a SQL query to be autocompleted.
+
+        Returns
+        str : The sql autocompletion
+        -------
+        """
         prompt = {
             "{{input}}": sql_prompt,
             "{{examples}}": "\nEND".join(self.example_queries),
@@ -43,7 +53,7 @@ class AutocompleteSQLModel:
             stop=['\\\\nEND', '\\nEND', '\nEND', ';'],
             temperature=0.7,
             model=self.model_name)
-        print(output)
+
         return self.post_process(output)
 
     def post_process(self, output):
