@@ -19,7 +19,8 @@ class CreateTopicsModel:
             self,
             config={},
             num_subsamples=10,
-            max_output_tokens=256,):
+            max_output_tokens=256,
+            random_seed=None):
         # This is a hack to silence printed message on import
         sys.stdout = open(os.devnull, 'w')
         sys.stderr = open(os.devnull, 'w')
@@ -28,6 +29,8 @@ class CreateTopicsModel:
         sys.stdout = sys.__stdout__
         sys.stderr = sys.__stderr__
 
+        if random_seed is not None:
+            random.seed(random_seed)
         self.model = PowerML(config)
         self.create_model_name = "unblocked/create-topics/v2"
         self.messages = []
@@ -35,14 +38,20 @@ class CreateTopicsModel:
         self.sample_size = 20
         self.max_output_tokens = max_output_tokens
         self.memo_topics = {}
-        self.memo_top_topics = {}
         self.tokenizer = GPT2Tokenizer.from_pretrained("gpt2")
         logging.set_verbosity(40)
 
     def fit(self, documents, topic_type):
+        """
+        Parameters
+        ----------
+        documents : list[str]
+            A list of text documents which discuss various topics
+        topic_type : str
+            A description of the topics to be extracted from the documents
+        """
         self.topic_type = topic_type
         self.messages = documents
-        random.shuffle(self.messages)
         self.num_samples = len(self.messages)
         if self.num_subsamples * self.sample_size > self.num_samples:
             self.num_subsamples = self.num_samples // self.sample_size
@@ -50,6 +59,14 @@ class CreateTopicsModel:
                 self.messages) % self.sample_size else 0
 
     def predict(self):
+        """
+        Returns
+        -------
+        list[{
+            "name": str,
+            "score": float,
+        }] : a list of dictionaries with generated topic names and scores
+        """
         # If get_topics has been called on the same messages array
         # Then use the previous results
         hash_docs = hash(frozenset(self.messages))
@@ -59,12 +76,13 @@ class CreateTopicsModel:
         sample_index = 0
         topic_counter = Counter()
         print("Learning topics...")
+        queue = random.sample(self.messages, self.num_samples)
         for _ in tqdm(range(self.num_subsamples), ncols=0):
             if sample_index > self.num_samples:
                 break
-            examples, sample_index = self.__subsample(
-                self.messages, sample_index, self.sample_size)
             prompt = self.__prompt_format(self.topic_type)
+            examples, sample_index = self.__subsample(
+                queue, sample_index, self.sample_size)
             prompt = self.__add_examples(examples, prompt)
             output = self.model.predict(
                 prompt, max_tokens=self.max_output_tokens, temperature=0.7, model=self.create_model_name)
@@ -73,8 +91,6 @@ class CreateTopicsModel:
             sorted_topics = self.__sort_topics(topic_counter)
         topics = self.__get_topics(sorted_topics)
         self.memo_topics[hash_docs] = topics
-        top_topics = self.__get_top_topics(sorted_topics)
-        self.memo_top_topics[hash_docs] = top_topics
         return topics
 
     def __count_tokens(self, string):
@@ -94,8 +110,6 @@ class CreateTopicsModel:
             prompt_dict[key] = example
             if self.__count_tokens(str(prompt_dict)) > max_total_tokens - self.max_output_tokens:
                 prompt_dict[key] = ""
-                # TODO: in this case, not all examples have been subsampled. Ideally we should return the examples
-                # which have not been subsampled to the back of a queue.
                 break
         return prompt_dict
 
@@ -111,17 +125,19 @@ class CreateTopicsModel:
         return parsed
 
     def __subsample(self, data, start_index, sample_size):
-        # Assume data is pre-shuffled
-        end_index = start_index + sample_size
-        return data[start_index:end_index], end_index
+        examples = []
+        token_count = 0
+        end_index = min(start_index + sample_size, self.num_samples)
+        for index in range(start_index, end_index):
+            token_count += self.__count_tokens(data[index])
+            if token_count > MAX_TOTAL_TOKENS:
+                return examples, index
+            examples.append(data[index])
+        return examples, index
 
     def __sort_topics(self, topic_counter):
         return sorted(topic_counter.items(), key=lambda x: x[1], reverse=True)
 
     def __get_topics(self, sorted_topics):
         # Return and save all topics
-        return [elt for elt, _ in sorted_topics]
-
-    def __get_top_topics(self, sorted_topics):
-        # Return and save all topics that have more than count 1
-        return [elt for elt, count in sorted_topics if count > 1]
+        return [{"name": elt, "score": count/self.num_subsamples} for elt, count in sorted_topics]
