@@ -1,7 +1,7 @@
 import io
 import requests
 import jsonlines
-from powerml.utils.run_ai import query_powerml
+from powerml.utils.run_ai import query_powerml, powerml_train
 from powerml.utils.config import get_config
 import logging
 
@@ -48,17 +48,11 @@ class PowerML:
         if model == "" or model is None:
             model = self.current_model
         logger.debug("Fit using model: " + model)
-        # Upload filtered data to train api
-        headers = {
-            "Authorization": "Bearer " + self.config["powerml.key"],
-            "Content-Type": "application/json", }
-        response = requests.post(
-            headers=headers,
-            url="https://api.staging.powerml.co/v1/train",
-            json={
-                "dataset": self.__make_dataset_string(data),
-                "model": model
-            })
+        params = {
+            "dataset": self.__make_dataset_string(data),
+            "model": model
+        }
+        response = powerml_train(params, self.config["powerml.key"])
         model_details = response.json()['model']
         self.current_model = model_details["model_name"]
         return model_details
